## Generating mock data

::: jaxspec.data.util.fakeit_for_multiple_parameters
    options:
      show_root_heading: true
      show_root_full_path: false
      show_root_toc_entry: true
      heading_level: 3

## Data containers

::: jaxspec.data.obsconf
    options:
      show_root_heading: false
      show_root_toc_entry: false
      heading_level: 3

::: jaxspec.data.instrument
    options:
      show_root_heading: false
      show_root_toc_entry: false
      heading_level: 3

::: jaxspec.data.observation
    options:
      show_root_heading: false
      show_root_toc_entry: false
      heading_level: 3

## OGIP data parsers

::: jaxspec.data.ogip
    options:
      show_root_heading: false
      show_root_toc_entry: false
      heading_level: 3